==> openpyweb-2.0.5b30.tar.gz: openpyweb-2.0.5b30/README.md <==
# Openpyweb

[![Build Status](https://img.shields.io/pypi/v/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![Downloads](https://pepy.tech/badge/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![Wheel](https://img.shields.io/pypi/wheel/openpyweb.svg)](https://pypi.python.org/pypi/openpyweb)
[![Python Version](https://img.shields.io/pypi/pyversions/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![License](https://img.shields.io/pypi/l/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![Gitter](https://badges.gitter.im/openpyweb/community.svg)](https://gitter.im/openpyweb/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Docs](https://img.shields.io/readthedocs/openpyweb)](https://openpyweb.readthedocs.io/en/latest)
[![lint_python](https://github.com/openpyweb/openpyweb/workflows/lint_python/badge.svg)](https://github.com/openpyweb/openpyweb/actions)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-green.svg)](https://github.com/openpyweb/openpyweb/blob/master/CONTRIBUTING.md)

> openpyweb is a python framework built to enhance fast and easy web development, helping web developers build more apps with fewer codes.
> The framework uses an Expressive Architectural Pattern, structured on a Model-View-Controller (MVC), and bundles of components to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/openpyweb)

## How to setup

openpyweb provides an inbuilt server for deployment and can as well be run on, WAMP, XAMPP, LAMP or MAMP, using CGI.

To Create openpyweb Project Folder

```
$ openpyweb-start
```

To Run openpyweb Server

```
$ openpyweb-server
```

To Install Project Requirements from `requirements.txt` file.

```
$ openpyweb-install
```

To Read openpyweb Docs

```
$ openpyweb-docs
```

## 🤝 Contributing

Contributions, issues and feature requests are welcome!

Feel free to check the [issues page](https://github.com/openpyweb/openpyweb/issues).

For guidance on setting up a development environment and how to make a contribution to openpyweb, see the [contributing guidelines.](https://github.com/openpyweb/openpyweb/blob/master/CONTRIBUTING.md)

## Documentation on how to?

- [Getting Started](https://openpyweb.readthedocs.io/en/latest)

## Assistance

Having issue using or implementing modules and functions, upload your openpyweb project on github, open an issues. our contributors and maintainers will look into it.

## Show your support

Give a ⭐️ if you like this project!

## Contact

**Name:** Emmanuel Essien

**Email:** emmanuelessiens@outlook.com

==> openpyweb-2.1.0.tar.gz: openpyweb-2.1.0/README.md <==
# Openpyweb

[![Build Status](https://img.shields.io/pypi/v/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![Downloads](https://pepy.tech/badge/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![Wheel](https://img.shields.io/pypi/wheel/openpyweb.svg)](https://pypi.python.org/pypi/openpyweb)
[![Python Version](https://img.shields.io/pypi/pyversions/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![License](https://img.shields.io/pypi/l/openpyweb)](https://pypi.python.org/pypi/openpyweb)
[![Gitter](https://badges.gitter.im/openpyweb/community.svg)](https://gitter.im/openpyweb/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Docs](https://img.shields.io/readthedocs/openpyweb)](https://openpyweb.readthedocs.io/en/latest)
[![lint_python](https://github.com/emmanuelessiens/openpyweb/workflows/lint_python/badge.svg)](https://github.com/emmanuelessiens/openpyweb/actions)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-green.svg)](https://github.com/emmanuelessiens/openpyweb/blob/master/CONTRIBUTING.md)

> openpyweb is a python framework built to enhance fast and easy web development, helping web developers build more apps with fewer codes.
> The framework uses an Expressive Architectural Pattern, structured on a Model-View-Controller (MVC), and bundles of components to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/openpyweb)

## How to setup

openpyweb provides an inbuilt server for deployment and can as well be run on, WAMP, XAMPP, LAMP or MAMP, using CGI.

To Create openpyweb Project Folder

```
$ openpyweb-start
```

To Run openpyweb Server

```
$ openpyweb-server
```

To Install Project Requirements from `requirements.txt` file.

```
$ openpyweb-install
```

To Read openpyweb Docs

```
$ openpyweb-docs
```

## 🤝 Contributing

Contributions, issues and feature requests are welcome!

Feel free to check the [issues page](https://github.com/emmanuelessiens/openpyweb/issues).

For guidance on setting up a development environment and how to make a contribution to openpyweb, see the [contributing guidelines.](https://github.com/emmanuelessiens/openpyweb/blob/master/CONTRIBUTING.md)

## Documentation on how to?

- [Getting Started](https://openpyweb.readthedocs.io/en/latest)

## Assistance

Having issue using or implementing modules and functions, upload your openpyweb project on github, open an issues. our contributors and maintainers will look into it.

## Show your support

Give a ⭐️ if you like this project!

Support openpyweb and the libraries it uses. In order to grow the community of contributors and users, and allow the maintainers to devote more time to the projects, [please donate today.](https://liberapay.com/openpyweb/)

## Contact

**Name:** Emmanuel Essien

**Email:** emmanuelessiens@outlook.com
